#
# @file    TestRDFAnnotation.py
# @brief   fomula units data unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Ben Bornstein
 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestRDFAnnotation.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def wrapString(s):
  return s
  pass


class TestRDFAnnotation(unittest.TestCase):

  global d
  d = None
  global m
  m = None

  def equals(self, *x):
    if len(x) == 2:
      return x[0] == x[1]
    elif len(x) == 1:
      return x[0] == self.OSS.str()

  def setUp(self):
    filename = "../../sbml/annotation/test/test-data/annotation.xml"
    self.d = libsbml.readSBML(filename)
    self.m = self.d.getModel()
    pass  

  def tearDown(self):
    self.d = None
    pass  

  def test_RDFAnnotation_delete(self):
    node = libsbml.RDFAnnotationParser.parseCVTerms(self.m.getCompartment(0))
    n1 = libsbml.RDFAnnotationParser.deleteRDFAnnotation(node)
    expected =  "<annotation/>";
    self.assertTrue( n1.getNumChildren() == 0 )
    self.assertTrue( n1.getName() ==  "annotation" )
    self.assertEqual( True, self.equals(expected,n1.toXMLString()) )
    node = None
    pass  

  def test_RDFAnnotation_deleteCVTerms(self):
    node = self.m.getCompartment(0).getAnnotation()
    n1 = None
    empty =  "<annotation/>";
    noRDF = wrapString("<annotation>\n"
"  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n"
    "    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>\n"
 + 
    "</annotation>")
    otherRDF = wrapString("<annotation>\n"
 + 
    "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n"
 + 
    "    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>\n"
 + 
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "    <rdf:Description>\n"
 + 
    "      <rdf:other/>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "  </rdf:RDF>\n"
 + 
    "</annotation>")
    n1 = libsbml.RDFAnnotationParser.deleteRDFCVTermAnnotation(None)
    self.assertTrue( n1 == None )
    n1 = libsbml.RDFAnnotationParser.deleteRDFCVTermAnnotation(node)
    self.assertTrue( n1.getNumChildren() == 0 )
    self.assertTrue( n1.getName() ==  "annotation" )
    self.assertEqual( True, self.equals(empty,n1.toXMLString()) )
    node = self.m.getCompartment(2).getAnnotation()
    n1 = libsbml.RDFAnnotationParser.deleteRDFCVTermAnnotation(node)
    self.assertEqual( True, self.equals(noRDF,n1.toXMLString()) )
    node = self.m.getCompartment(1).getAnnotation()
    n1 = libsbml.RDFAnnotationParser.deleteRDFCVTermAnnotation(node)
    self.assertEqual( True, self.equals(noRDF,n1.toXMLString()) )
    node = self.m.getCompartment(4).getAnnotation()
    n1 = libsbml.RDFAnnotationParser.deleteRDFCVTermAnnotation(node)
    self.assertEqual( True, self.equals(otherRDF,n1.toXMLString()) )
    node = libsbml.XMLNode.convertStringToXMLNode("<notannotatio/>")
    n1 = libsbml.RDFAnnotationParser.deleteRDFCVTermAnnotation(node)
    self.assertTrue( n1 == None )
    pass  

  def test_RDFAnnotation_deleteWithOther(self):
    c = self.m.getCompartment(1)
    node = libsbml.RDFAnnotationParser.deleteRDFAnnotation(c.getAnnotation())
    expected = wrapString("<annotation>\n" + "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n" + 
    "    <jd2:header>\n" + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n" + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n" + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n" + 
    "    </jd2:header>\n" + 
    "  </jd2:JDesignerLayout>\n" + 
    "</annotation>")
    self.assertEqual( True, self.equals(expected,node.toXMLString()) )
    pass  

  def test_RDFAnnotation_deleteWithOtherRDF(self):
    c = self.m.getCompartment(5)
    node = c.getAnnotation()
    expected = wrapString("<annotation>\n"
"  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n"
 + 
    "    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>\n"
 + 
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "    <rdf:Description>\n"
 + 
    "      <rdf:other/>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "  </rdf:RDF>\n"
 + 
    "</annotation>")
    self.assertEqual( True, self.equals(expected,node.toXMLString()) )
    pass  

  def test_RDFAnnotation_deleteWithOutOther(self):
    c = self.m.getCompartment(2)
    node = c.getAnnotation()
    expected = wrapString("<annotation>\n" + "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n" + 
    "    <jd2:header>\n" + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n" + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n" + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n" + 
    "    </jd2:header>\n" + 
    "  </jd2:JDesignerLayout>\n" + 
    "</annotation>")
    self.assertEqual( True, self.equals(expected,node.toXMLString()) )
    pass  

  def test_RDFAnnotation_getModelHistory(self):
    self.assertTrue( (self.m == None) == False )
    history = self.m.getModelHistory()
    self.assertTrue( history != None )
    mc = history.getCreator(0)
    self.assertTrue((  "Le Novere" == mc.getFamilyName() ))
    self.assertTrue((  "Nicolas" == mc.getGivenName() ))
    self.assertTrue((  "lenov@ebi.ac.uk" == mc.getEmail() ))
    self.assertTrue((  "EMBL-EBI" == mc.getOrganisation() ))
    date = history.getCreatedDate()
    self.assertTrue( date.getYear() == 2005 )
    self.assertTrue( date.getMonth() == 2 )
    self.assertTrue( date.getDay() == 2 )
    self.assertTrue( date.getHour() == 14 )
    self.assertTrue( date.getMinute() == 56 )
    self.assertTrue( date.getSecond() == 11 )
    self.assertTrue( date.getSignOffset() == 0 )
    self.assertTrue( date.getHoursOffset() == 0 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    self.assertTrue((  "2005-02-02T14:56:11Z" == date.getDateAsString() ))
    date = history.getModifiedDate()
    self.assertTrue( date.getYear() == 2006 )
    self.assertTrue( date.getMonth() == 5 )
    self.assertTrue( date.getDay() == 30 )
    self.assertTrue( date.getHour() == 10 )
    self.assertTrue( date.getMinute() == 46 )
    self.assertTrue( date.getSecond() == 2 )
    self.assertTrue( date.getSignOffset() == 0 )
    self.assertTrue( date.getHoursOffset() == 0 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    self.assertTrue((  "2006-05-30T10:46:02Z" == date.getDateAsString() ))
    pass  

  def test_RDFAnnotation_parseCVTerms(self):
    node = libsbml.RDFAnnotationParser.parseCVTerms(self.m.getCompartment(0))
    self.assertTrue( node.getNumChildren() == 1 )
    rdf = node.getChild(0)
    self.assertTrue((  "RDF" == rdf.getName() ))
    self.assertTrue((  "rdf" == rdf.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == rdf.getURI() ))
    self.assertTrue( rdf.getNumChildren() == 1 )
    desc = rdf.getChild(0)
    self.assertTrue((  "Description" == desc.getName() ))
    self.assertTrue((  "rdf" == desc.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == desc.getURI() ))
    self.assertTrue( desc.getNumChildren() == 1 )
    is1 = desc.getChild(0)
    self.assertTrue((  "is" == is1.getName() ))
    self.assertTrue((  "bqbiol" == is1.getPrefix() ))
    self.assertTrue( is1.getNumChildren() == 1 )
    Bag = is1.getChild(0)
    self.assertTrue((  "Bag" == Bag.getName() ))
    self.assertTrue((  "rdf" == Bag.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == Bag.getURI() ))
    self.assertTrue( Bag.getNumChildren() == 4 )
    li = Bag.getChild(0)
    self.assertTrue((  "li" == li.getName() ))
    self.assertTrue((  "rdf" == li.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li.getURI() ))
    self.assertTrue( li.getNumChildren() == 0 )
    li1 = Bag.getChild(1)
    self.assertTrue((  "li" == li1.getName() ))
    self.assertTrue((  "rdf" == li1.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li1.getURI() ))
    self.assertTrue( li1.getNumChildren() == 0 )
    li2 = Bag.getChild(2)
    self.assertTrue((  "li" == li2.getName() ))
    self.assertTrue((  "rdf" == li2.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li2.getURI() ))
    self.assertTrue( li2.getNumChildren() == 0 )
    li3 = Bag.getChild(3)
    self.assertTrue((  "li" == li3.getName() ))
    self.assertTrue((  "rdf" == li3.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li3.getURI() ))
    self.assertTrue( li3.getNumChildren() == 0 )
    node = None
    node1 = libsbml.RDFAnnotationParser.parseCVTerms(None)
    self.assertTrue( node1 == None )
    node1 = libsbml.RDFAnnotationParser.createCVTerms(None)
    self.assertTrue( node1 == None )
    node1 = libsbml.RDFAnnotationParser.parseCVTerms(self.m.getCompartment(2))
    self.assertTrue( node1 == None )
    node1 = libsbml.RDFAnnotationParser.createCVTerms(self.m.getCompartment(2))
    self.assertTrue( node1 == None )
    node1 = libsbml.RDFAnnotationParser.parseCVTerms(self.m)
    self.assertTrue( node1 == None )
    node1 = libsbml.RDFAnnotationParser.createCVTerms(self.m)
    self.assertTrue( node1 == None )
    c = libsbml.Compartment(3,1)
    c.setMetaId("_002")
    node1 = libsbml.RDFAnnotationParser.parseCVTerms(c)
    self.assertTrue( node1 == None )
    node1 = libsbml.RDFAnnotationParser.createCVTerms(c)
    self.assertTrue( node1 == None )
    cv = libsbml.CVTerm(libsbml.BIOLOGICAL_QUALIFIER)
    cv.setBiologicalQualifierType(23)
    cv.addResource("http://myres")
    c.addCVTerm(cv)
    node1 = libsbml.RDFAnnotationParser.createCVTerms(c)
    self.assertTrue( node1 == None )
    c = None
    m1 = libsbml.Model(3,1)
    m1.setMetaId("_002")
    cv = libsbml.CVTerm(libsbml.MODEL_QUALIFIER)
    cv.setModelQualifierType(23)
    cv.addResource("http://myres")
    m1.addCVTerm(cv)
    node1 = libsbml.RDFAnnotationParser.createCVTerms(m1)
    self.assertTrue( node1 == None )
    pass  

  def test_RDFAnnotation_parseModelHistory(self):
    node = libsbml.RDFAnnotationParser.parseModelHistory(self.m)
    self.assertTrue( node.getNumChildren() == 1 )
    rdf = node.getChild(0)
    self.assertTrue((  "RDF" == rdf.getName() ))
    self.assertTrue((  "rdf" == rdf.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == rdf.getURI() ))
    self.assertTrue( rdf.getNumChildren() == 1 )
    desc = rdf.getChild(0)
    self.assertTrue((  "Description" == desc.getName() ))
    self.assertTrue((  "rdf" == desc.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == desc.getURI() ))
    self.assertTrue( desc.getNumChildren() == 3 )
    creator = desc.getChild(0)
    self.assertTrue((  "creator" == creator.getName() ))
    self.assertTrue((  "dc" == creator.getPrefix() ))
    self.assertTrue( creator.getNumChildren() == 1 )
    Bag = creator.getChild(0)
    self.assertTrue((  "Bag" == Bag.getName() ))
    self.assertTrue((  "rdf" == Bag.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == Bag.getURI() ))
    self.assertTrue( Bag.getNumChildren() == 1 )
    li = Bag.getChild(0)
    self.assertTrue((  "li" == li.getName() ))
    self.assertTrue((  "rdf" == li.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li.getURI() ))
    self.assertTrue( li.getNumChildren() == 3 )
    N = li.getChild(0)
    self.assertTrue((  "N" == N.getName() ))
    self.assertTrue((  "vCard" == N.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == N.getURI() ))
    self.assertTrue( N.getNumChildren() == 2 )
    Family = N.getChild(0)
    self.assertTrue((  "Family" == Family.getName() ))
    self.assertTrue((  "vCard" == Family.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Family.getURI() ))
    self.assertTrue( Family.getNumChildren() == 1 )
    Given = N.getChild(1)
    self.assertTrue((  "Given" == Given.getName() ))
    self.assertTrue((  "vCard" == Given.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Given.getURI() ))
    self.assertTrue( Given.getNumChildren() == 1 )
    EMAIL = li.getChild(1)
    self.assertTrue((  "EMAIL" == EMAIL.getName() ))
    self.assertTrue((  "vCard" == EMAIL.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == EMAIL.getURI() ))
    self.assertTrue( EMAIL.getNumChildren() == 1 )
    ORG = li.getChild(2)
    self.assertTrue((  "ORG" == ORG.getName() ))
    self.assertTrue((  "vCard" == ORG.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == ORG.getURI() ))
    self.assertTrue( ORG.getNumChildren() == 1 )
    Orgname = ORG.getChild(0)
    self.assertTrue((  "Orgname" == Orgname.getName() ))
    self.assertTrue((  "vCard" == Orgname.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Orgname.getURI() ))
    self.assertTrue( Orgname.getNumChildren() == 1 )
    created = desc.getChild(1)
    self.assertTrue((  "created" == created.getName() ))
    self.assertTrue((  "dcterms" == created.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == created.getURI() ))
    self.assertTrue( created.getNumChildren() == 1 )
    cr_date = created.getChild(0)
    self.assertTrue((  "W3CDTF" == cr_date.getName() ))
    self.assertTrue((  "dcterms" == cr_date.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == cr_date.getURI() ))
    self.assertTrue( cr_date.getNumChildren() == 1 )
    modified = desc.getChild(2)
    self.assertTrue((  "modified" == modified.getName() ))
    self.assertTrue((  "dcterms" == modified.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == modified.getURI() ))
    self.assertTrue( modified.getNumChildren() == 1 )
    mo_date = created.getChild(0)
    self.assertTrue((  "W3CDTF" == mo_date.getName() ))
    self.assertTrue((  "dcterms" == mo_date.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == mo_date.getURI() ))
    self.assertTrue( mo_date.getNumChildren() == 1 )
    node = None
    pass  

  def test_RDFAnnotation_removeAnnotation(self):
    n1 = None
    expected = wrapString("<annotation>\n"
 + 
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "    <rdf:Description rdf:about=\"#_000005\">\n"
 + 
    "      <bqbiol:is>\n"
 + 
    "        <rdf:Bag>\n"
 + 
    "          <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "        </rdf:Bag>\n"
 + 
    "      </bqbiol:is>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "    <rdf:Description>\n"
 + 
    "      <rdf:other/>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "  </rdf:RDF>\n"
 + 
    "</annotation>")
    i = self.m.getCompartment(4).removeTopLevelAnnotationElement("JDesignerLayout")
    n1 = self.m.getCompartment(4).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.equals(expected,n1.toXMLString()) )
    i = self.m.getListOfCompartments().removeTopLevelAnnotationElement("RDF")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    pass  

  def test_RDFAnnotation_removeSingleAnnotation(self):
    n1 = None
    i = self.m.getCompartment(0).removeTopLevelAnnotationElement("RDF")
    n1 = self.m.getCompartment(0).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( n1 == None )
    i = self.m.getCompartment(2).removeTopLevelAnnotationElement("JDesignerLayout")
    n1 = self.m.getCompartment(2).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( n1 == None )
    i = self.m.getCompartment(3).removeTopLevelAnnotationElement("RDF", "http://www.w3.org/1999/02/22-rdf-syntax-ns#")
    n1 = self.m.getCompartment(3).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( n1 == None )
    pass  

  def test_RDFAnnotation_removeSingleAnnotation1(self):
    n1 = None
    i = self.m.getCompartment(0).removeTopLevelAnnotationElement("RDF1")
    n1 = self.m.getCompartment(0).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_ANNOTATION_NAME_NOT_FOUND )
    self.assertTrue( n1.getNumChildren() == 1 )
    i = self.m.getCompartment(2).removeTopLevelAnnotationElement("JDLayout")
    n1 = self.m.getCompartment(2).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_ANNOTATION_NAME_NOT_FOUND )
    self.assertTrue( n1.getNumChildren() == 1 )
    i = self.m.getCompartment(3).removeTopLevelAnnotationElement("RDF", "http://www.w3.org/1999/02/22-rdf-syntax-ns")
    n1 = self.m.getCompartment(3).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_ANNOTATION_NS_NOT_FOUND )
    self.assertTrue( n1.getNumChildren() == 1 )
    pass  

  def test_RDFAnnotation_replaceAnnotation(self):
    node = self.m.getCompartment(3).getAnnotation()
    n1 = None
    expected = wrapString("<annotation>\n"
 + 
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "    <rdf:Description rdf:about=\"#_000002\">\n"
 + 
    "      <bqbiol:is>\n"
 + 
    "        <rdf:Bag>\n"
 + 
    "          <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "        </rdf:Bag>\n"
 + 
    "      </bqbiol:is>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "  </rdf:RDF>\n"
 + 
    "</annotation>")
    i = self.m.getCompartment(0).replaceTopLevelAnnotationElement(node)
    n1 = self.m.getCompartment(0).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.equals(expected,n1.toXMLString()) )
    pass  

  def test_RDFAnnotation_replaceAnnotation1(self):
    n1 = None
    noRDF = wrapString("<annotation>\n"
"  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"3\" BuildVersion=\"41\">\n"
 + 
    "    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Sarah\" ModelVersion=\"0.0\" ModelTitle=\"mine\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"12\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>\n"
 + 
    "</annotation>")
    expected = wrapString("<annotation>\n"
 + 
    "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"3\" BuildVersion=\"41\">\n"
 + 
    "    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Sarah\" ModelVersion=\"0.0\" ModelTitle=\"mine\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"12\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>\n"
 + 
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "    <rdf:Description rdf:about=\"#_000005\">\n"
 + 
    "      <bqbiol:is>\n"
 + 
    "        <rdf:Bag>\n"
 + 
    "          <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "        </rdf:Bag>\n"
 + 
    "      </bqbiol:is>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "    <rdf:Description>\n"
 + 
    "      <rdf:other/>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "  </rdf:RDF>\n"
 + 
    "</annotation>")
    i = self.m.getCompartment(4).replaceTopLevelAnnotationElement(noRDF)
    n1 = self.m.getCompartment(4).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.equals(expected,n1.toXMLString()) )
    pass  

  def test_RDFAnnotation_replaceAnnotation2(self):
    n1 = None
    jd = wrapString("  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"3\" BuildVersion=\"41\">\n"
"    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Sarah\" ModelVersion=\"0.0\" ModelTitle=\"mine\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"12\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>")
    twoAnn = wrapString("<annotation>\n"
 + 
    "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"3\" BuildVersion=\"41\">\n"
 + 
    "    <jd2:header>\n"
 + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n"
 + 
    "      <jd2:ModelHeader Author=\"Sarah\" ModelVersion=\"0.0\" ModelTitle=\"mine\"/>\n"
 + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"12\" numberOfPoints=\"1000\"/>\n"
 + 
    "    </jd2:header>\n"
 + 
    "  </jd2:JDesignerLayout>\n"
 + 
    "  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "    <rdf:Description rdf:about=\"#_000005\">\n"
 + 
    "      <bqbiol:is>\n"
 + 
    "        <rdf:Bag>\n"
 + 
    "          <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "        </rdf:Bag>\n"
 + 
    "      </bqbiol:is>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "    <rdf:Description>\n"
 + 
    "      <rdf:other/>\n"
 + 
    "    </rdf:Description>\n"
 + 
    "  </rdf:RDF>\n"
 + 
    "</annotation>")
    i = self.m.getCompartment(4).replaceTopLevelAnnotationElement(twoAnn)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    i = self.m.getCompartment(4).replaceTopLevelAnnotationElement(jd)
    n1 = self.m.getCompartment(4).getAnnotation()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.equals(twoAnn,n1.toXMLString()) )
    pass  

  def test_RDFAnnotation_testAnnotationForMetaId(self):
    doc = libsbml.SBMLDocument( 3,1 )
    model = doc.createModel()
    self.assertTrue( model != None )
    model.setId("test1")
    term = libsbml.CVTerm( libsbml.MODEL_QUALIFIER )
    term.addResource("testResource")
    term.setModelQualifierType(libsbml.BQM_IS)
    model.setMetaId("t1")
    model.addCVTerm(term)
    model.setMetaId("")
    test = model.toSBML()
    self.assertTrue( test ==  "<model id=\"test1\"/>" )
    pass  


  def test_RDFAnnotation_testMissingAbout(self):
    withAbout = wrapString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 + 
    "  <annotation>\n"
 + 
    "    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "      <rdf:Description rdf:about=\"#_000004\">\n"
 + 
    "        <bqbiol:is>\n"
 + 
    "          <rdf:Bag>\n"
 + 
    "            <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "          </rdf:Bag>\n"
 + 
    "        </bqbiol:is>\n"
 + 
    "      </rdf:Description>\n"
 + 
    "    </rdf:RDF>\n"
 + 
    "  </annotation>")
    emptyAbout = wrapString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 + 
    "  <annotation>\n"
 + 
    "    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "      <rdf:Description rdf:about=\"\">\n"
 + 
    "        <bqbiol:is>\n"
 + 
    "          <rdf:Bag>\n"
 + 
    "            <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "          </rdf:Bag>\n"
 + 
    "        </bqbiol:is>\n"
 + 
    "      </rdf:Description>\n"
 + 
    "    </rdf:RDF>\n"
 + 
    "  </annotation>")
    noAbout = wrapString("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 + 
    "  <annotation>\n"
 + 
    "    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 + 
    "      <rdf:Description>\n"
 + 
    "        <bqbiol:is>\n"
 + 
    "          <rdf:Bag>\n"
 + 
    "            <rdf:li rdf:resource=\"http://www.geneontology.org/#GO:0007274\"/>\n"
 + 
    "          </rdf:Bag>\n"
 + 
    "        </bqbiol:is>\n"
 + 
    "      </rdf:Description>\n"
 + 
    "    </rdf:RDF>\n"
 + 
    "  </annotation>")
    cvTerms = libsbml.CVTermList()
    stream = libsbml.XMLInputStream( withAbout,False )
    node = libsbml.XMLNode( stream )
    libsbml.RDFAnnotationParser.parseRDFAnnotation(node,cvTerms)
    self.assertTrue( cvTerms.getSize() == 1 )
    cvTerms = None
    cvTerms = libsbml.CVTermList()
    libsbml.RDFAnnotationParser.parseRDFAnnotation(node,cvTerms )
    self.assertTrue( cvTerms.getSize() == 1 )
    cvTerms = None
    cvTerms = None
    cvTerms = libsbml.CVTermList()
    stream1 = libsbml.XMLInputStream( emptyAbout,False )
    node1 = libsbml.XMLNode( stream1 )
    libsbml.RDFAnnotationParser.parseRDFAnnotation(node1,cvTerms)
    self.assertTrue( cvTerms.getSize() == 0 )
    cvTerms = None
    cvTerms = None
    cvTerms = libsbml.CVTermList()
    stream2 = libsbml.XMLInputStream( noAbout,False )
    node2 = libsbml.XMLNode( stream2 )
    libsbml.RDFAnnotationParser.parseRDFAnnotation(node2,cvTerms)
    self.assertTrue( cvTerms.getSize() == 0 )
    cvTerms = None
    cvTerms = None
    pass  

  def test_RDFAnnotation_testMissingMetaId(self):
    doc = libsbml.SBMLDocument( 3,1 )
    model = doc.createModel()
    self.assertTrue( model != None )
    model.setId("test1")
    term = libsbml.CVTerm( libsbml.MODEL_QUALIFIER )
    term.addResource("testResource")
    term.setModelQualifierType(libsbml.BQM_IS)
    model.setMetaId("t1")
    model.addCVTerm(term)
    model.setMetaId("")
    test = model.toSBML()
    self.assertTrue( test ==  "<model id=\"test1\"/>" )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestRDFAnnotation))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
##
## \file    addModelHistory.py
## \brief   adds Model History to a model
## \author  Sarah Keating
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->

import sys
import os.path
from libsbml import *

def printStatus(message, status):
  statusString = ""
  if status == LIBSBML_OPERATION_SUCCESS:
    statusString = "succeeded"
  elif status == LIBSBML_INVALID_OBJECT:
    statusString = "invalid object"
  elif status == LIBSBML_OPERATION_FAILED:
    statusString = "operation failed"
  else:
    statusString = "unknown"

  print (message + statusString )


def main (args):
  """usage: addModelHistory <input-filename> <output-filename>
     Adds a model history to the model
  """
  if len(args) != 3:
    print(main.__doc__)
    sys.exit(2)


  d = readSBML(args[1])
  errors = d.getNumErrors()

  if errors > 0:
      print("Read Error(s):" )
      d.printErrors()
      print("Correct the above and re-run." )
  else:
      h = ModelHistory()

      c = ModelCreator()
      c.setFamilyName("Keating")
      c.setGivenName("Sarah")
      c.setEmail("sbml-team@caltech.edu")
      c.setOrganization("University of Hertfordshire")

      status = h.addCreator(c)
      printStatus("Status for addCreator: ", status)

      date = Date("1999-11-13T06:54:32")
      date2 = Date("2007-11-30T06:54:00-02:00")

      status = h.setCreatedDate(date)
      printStatus("Set created date:      ", status)

      status = h.setModifiedDate(date2)
      printStatus("Set modified date:     ", status)

      status = d.getModel().setModelHistory(h)
      printStatus("Set model history:     ", status)

      writeSBML(d, args[2])
  return errors


if __name__ == '__main__':
  main(sys.argv)  



#!/usr/bin/env python
##
## \file    addingEvidenceCodes_2.py
## \brief   adds evidence codes to a species in a model
## \author  Sarah Keating
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->

import sys
import os.path
from libsbml import *

def main (args):
  """usage: addingEvidenceCodes_2 <input-filename> <output-filename>
     Adds controlled vocabulary term to a species
  """
  if len(args) != 3:
    print(main.__doc__)
    sys.exit(2)

  d = readSBML(args[1])
  errors = d.getNumErrors()

  if errors > 0:
    print("Read Error(s):\n")
    d.printErrors()

    print("Correct the above and re-run.\n")
  else:
    n = d.getModel().getNumSpecies()
    if n <= 0:
        print("Model has no species.\n Cannot add CV terms\n")
    else:
        s = d.getModel().getSpecies(0)

        # check that the species has a metaid
        # no CVTerms will be added if there is no metaid to reference
        # 
        if not s.isSetMetaId():
            s.setMetaId("metaid_0000052")

        cv1 = CVTerm(BIOLOGICAL_QUALIFIER)
        cv1.setBiologicalQualifierType(BQB_OCCURS_IN)
        cv1.addResource("urn:miriam:obo.go:GO%3A0005764")

        s.addCVTerm(cv1)

        # now create the additional annotation

        # <rdf:Statement> 
        #   <rdf:subject rdf:resource="#metaid_0000052"/> 
        #   <rdf:predicate rdf:resource="http://biomodels.net/biology-qualifiers/occursIn"/> 
        #   <rdf:object rdf:resource="urn:miriam:obo.go:GO%3A0005764"/> 
        #   <bqbiol:isDescribedBy> 
        #     <rdf:Bag> 
        #       <rdf:li rdf:resource="urn:miriam:obo.eco:ECO%3A0000004"/> 
        #       <rdf:li rdf:resource="urn:miriam:pubmed:7017716"/> 
        #     </rdf:Bag> 
        #   </bqbiol:isDescribedBy> 
        # </rdf:Statement> 

        # attributes
        blank_att = XMLAttributes()

        resource_att = XMLAttributes()

        #  create the outer statement node 
        statement_triple = XMLTriple("Statement",
                                               "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                               "rdf")

        statement_token = XMLToken(statement_triple, blank_att)

        statement = XMLNode(statement_token)

        # create the subject node
        subject_triple = XMLTriple("subject",
                                             "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                             "rdf")

        resource_att.clear()
        resource_att.add("rdf:resource", "#" + s.getMetaId())

        subject_token = XMLToken(subject_triple, resource_att)

        subject = XMLNode(subject_token)

        #create the predicate node
        predicate_triple = XMLTriple("predicate",
                                               "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                               "rdf")

        resource_att.clear()
        resource_att.add("rdf:resource",
                         "http://biomodels.net/biology-qualifiers/occursIn")

        predicate_token = XMLToken(predicate_triple, resource_att)

        predicate = XMLNode(predicate_token)

        #create the object node 
        object_triple = XMLTriple("object",
                                            "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                            "rdf")

        resource_att.clear()
        resource_att.add("rdf:resource", "urn:miriam:obo.go:GO%3A0005764")

        object_token = XMLToken(object_triple, resource_att)

        object_ = XMLNode(object_token)

        # create the bqbiol node 
        bqbiol_triple = XMLTriple("isDescribedBy",
                                            "http://biomodels.net/biology-qualifiers/",
                                            "bqbiol")

        bqbiol_token = XMLToken(bqbiol_triple, blank_att)

        bqbiol = XMLNode(bqbiol_token)

        # create the bag node 
        bag_triple = XMLTriple("Bag",
                                         "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                         "rdf")

        bag_token = XMLToken(bag_triple, blank_att)

        bag = XMLNode(bag_token)

        # create each li node and add to the bag 
        li_triple = XMLTriple("li",
                                        "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                        "rdf")

        resource_att.clear()
        resource_att.add("rdf:resource", "urn:miriam:obo.eco:ECO%3A0000004")

        li_token = XMLToken(li_triple, resource_att)
        li_token.setEnd()

        li = XMLNode(li_token)

        bag.addChild(li)

        resource_att.clear()
        resource_att.add("rdf:resource", "urn:miriam:pubmed:7017716")
        li_token = XMLToken(li_triple, resource_att)
        li_token.setEnd()
        li = XMLNode(li_token)

        bag.addChild(li)

        # add the bag to bqbiol 
        bqbiol.addChild(bag)

        # add subject, predicate, object and bqbiol to statement 
        statement.addChild(subject)
        statement.addChild(predicate)
        statement.addChild(object_)
        statement.addChild(bqbiol)

        # create a top-level RDF element
        # this will ensure correct merging
        # 

        xmlns = XMLNamespaces()
        xmlns.add("http://www.w3.org/1999/02/22-rdf-syntax-ns#", "rdf")
        xmlns.add("http://purl.org/dc/elements/1.1/", "dc")
        xmlns.add("http://purl.org/dc/terms/", "dcterms")
        xmlns.add("http://www.w3.org/2001/vcard-rdf/3.0#", "vCard")
        xmlns.add("http://biomodels.net/biology-qualifiers/", "bqbiol")
        xmlns.add("http://biomodels.net/model-qualifiers/", "bqmodel")

        RDF_triple = XMLTriple("RDF",
                                         "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
                                         "rdf")

        RDF_token = XMLToken(RDF_triple, blank_att, xmlns)

        annotation = XMLNode(RDF_token)

        # add the staement node to the RDF node 
        annotation.addChild(statement)

        s.appendAnnotation(annotation)

        writeSBML(d, args[2])

  return errors


if __name__ == '__main__':
  main(sys.argv)  



#
# @file    TestModel_newSetters.py
# @brief   Model unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestModel_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestModel_newSetters(unittest.TestCase):

  global M
  M = None

  def setUp(self):
    self.M = libsbml.Model(2,4)
    if (self.M == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.M ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartment1(self):
    m = libsbml.Model(2,2)
    c = libsbml.Compartment(2,2)
    i = m.addCompartment(c)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    c.setId( "c")
    i = m.addCompartment(c)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumCompartments() == 1 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartment2(self):
    m = libsbml.Model(2,2)
    c = libsbml.Compartment(2,1)
    c.setId( "c")
    i = m.addCompartment(c)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumCompartments() == 0 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartment3(self):
    m = libsbml.Model(2,2)
    c = libsbml.Compartment(1,2)
    c.setId( "c")
    i = m.addCompartment(c)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumCompartments() == 0 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartment4(self):
    m = libsbml.Model(2,2)
    c = None
    i = m.addCompartment(c)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumCompartments() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartment5(self):
    m = libsbml.Model(2,2)
    c = libsbml.Compartment(2,2)
    c.setId( "c")
    c1 = libsbml.Compartment(2,2)
    c1.setId( "c")
    i = m.addCompartment(c)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumCompartments() == 1 )
    i = m.addCompartment(c1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumCompartments() == 1 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ c1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartmentType1(self):
    m = libsbml.Model(2,2)
    ct = libsbml.CompartmentType(2,2)
    i = m.addCompartmentType(ct)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    ct.setId( "ct")
    i = m.addCompartmentType(ct)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumCompartmentTypes() == 1 )
    _dummyList = [ ct ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartmentType2(self):
    m = libsbml.Model(2,2)
    ct = libsbml.CompartmentType(2,3)
    ct.setId( "ct")
    i = m.addCompartmentType(ct)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumCompartmentTypes() == 0 )
    _dummyList = [ ct ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartmentType3(self):
    m = libsbml.Model(2,2)
    ct = None
    i = m.addCompartmentType(ct)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumCompartmentTypes() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addCompartmentType4(self):
    m = libsbml.Model(2,2)
    ct = libsbml.CompartmentType(2,2)
    ct.setId( "ct")
    ct1 = libsbml.CompartmentType(2,2)
    ct1.setId( "ct")
    i = m.addCompartmentType(ct)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumCompartmentTypes() == 1 )
    i = m.addCompartmentType(ct1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumCompartmentTypes() == 1 )
    _dummyList = [ ct ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ct1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addConstraint1(self):
    m = libsbml.Model(2,2)
    c = libsbml.Constraint(2,2)
    i = m.addConstraint(c)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    c.setMath(libsbml.parseFormula("a+b"))
    i = m.addConstraint(c)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumConstraints() == 1 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addConstraint2(self):
    m = libsbml.Model(2,2)
    c = libsbml.Constraint(2,3)
    c.setMath(libsbml.parseFormula("a+b"))
    i = m.addConstraint(c)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumConstraints() == 0 )
    _dummyList = [ c ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addConstraint3(self):
    m = libsbml.Model(2,2)
    c = None
    i = m.addConstraint(c)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumConstraints() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addEvent1(self):
    m = libsbml.Model(2,2)
    e = libsbml.Event(2,2)
    t = libsbml.Trigger(2,2)
    i = m.addEvent(e)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    t.setMath(libsbml.parseFormula("true"))
    e.setTrigger(t)
    i = m.addEvent(e)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    e.createEventAssignment()
    i = m.addEvent(e)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumEvents() == 1 )
    _dummyList = [ e ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addEvent2(self):
    m = libsbml.Model(2,2)
    e = libsbml.Event(2,1)
    t = libsbml.Trigger(2,1)
    t.setMath(libsbml.parseFormula("true"))
    e.setTrigger(t)
    e.createEventAssignment()
    i = m.addEvent(e)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumEvents() == 0 )
    _dummyList = [ e ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addEvent3(self):
    m = libsbml.Model(2,2)
    e = None
    i = m.addEvent(e)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumEvents() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addEvent4(self):
    m = libsbml.Model(2,2)
    e = libsbml.Event(2,2)
    t = libsbml.Trigger(2,2)
    t.setMath(libsbml.parseFormula("true"))
    e.setId( "e")
    e.setTrigger(t)
    e.createEventAssignment()
    e1 = libsbml.Event(2,2)
    e1.setId( "e")
    e1.setTrigger(t)
    e1.createEventAssignment()
    i = m.addEvent(e)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumEvents() == 1 )
    i = m.addEvent(e1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumEvents() == 1 )
    _dummyList = [ e ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ e1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addFunctionDefinition1(self):
    m = libsbml.Model(2,2)
    fd = libsbml.FunctionDefinition(2,2)
    i = m.addFunctionDefinition(fd)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    fd.setId( "fd")
    i = m.addFunctionDefinition(fd)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    fd.setMath(libsbml.parseFormula("fd"))
    i = m.addFunctionDefinition(fd)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumFunctionDefinitions() == 1 )
    _dummyList = [ fd ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addFunctionDefinition2(self):
    m = libsbml.Model(2,2)
    fd = libsbml.FunctionDefinition(2,1)
    fd.setId( "fd")
    fd.setMath(libsbml.parseFormula("fd"))
    i = m.addFunctionDefinition(fd)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumFunctionDefinitions() == 0 )
    _dummyList = [ fd ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addFunctionDefinition3(self):
    m = libsbml.Model(2,2)
    fd = None
    i = m.addFunctionDefinition(fd)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumFunctionDefinitions() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addFunctionDefinition4(self):
    m = libsbml.Model(2,2)
    fd = libsbml.FunctionDefinition(2,2)
    fd.setId( "fd")
    fd.setMath(libsbml.parseFormula("fd"))
    fd1 = libsbml.FunctionDefinition(2,2)
    fd1.setId( "fd")
    fd1.setMath(libsbml.parseFormula("fd"))
    i = m.addFunctionDefinition(fd)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumFunctionDefinitions() == 1 )
    i = m.addFunctionDefinition(fd1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumFunctionDefinitions() == 1 )
    _dummyList = [ fd ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ fd1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addInitialAssignment1(self):
    m = libsbml.Model(2,2)
    ia = libsbml.InitialAssignment(2,2)
    i = m.addInitialAssignment(ia)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    ia.setSymbol( "i")
    i = m.addInitialAssignment(ia)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    ia.setMath(libsbml.parseFormula("gg"))
    i = m.addInitialAssignment(ia)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumInitialAssignments() == 1 )
    _dummyList = [ ia ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addInitialAssignment2(self):
    m = libsbml.Model(2,2)
    ia = libsbml.InitialAssignment(2,3)
    ia.setSymbol( "i")
    ia.setMath(libsbml.parseFormula("gg"))
    i = m.addInitialAssignment(ia)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumInitialAssignments() == 0 )
    _dummyList = [ ia ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addInitialAssignment3(self):
    m = libsbml.Model(2,2)
    ia = None
    i = m.addInitialAssignment(ia)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumInitialAssignments() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addInitialAssignment4(self):
    m = libsbml.Model(2,2)
    ia = libsbml.InitialAssignment(2,2)
    ia.setSymbol( "ia")
    ia.setMath(libsbml.parseFormula("a+b"))
    ia1 = libsbml.InitialAssignment(2,2)
    ia1.setSymbol( "ia")
    ia1.setMath(libsbml.parseFormula("a+b"))
    i = m.addInitialAssignment(ia)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumInitialAssignments() == 1 )
    i = m.addInitialAssignment(ia1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumInitialAssignments() == 1 )
    _dummyList = [ ia ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ia1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addParameter1(self):
    m = libsbml.Model(2,2)
    p = libsbml.Parameter(2,2)
    i = m.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    p.setId( "p")
    i = m.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumParameters() == 1 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addParameter2(self):
    m = libsbml.Model(2,2)
    p = libsbml.Parameter(2,1)
    p.setId( "p")
    i = m.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumParameters() == 0 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addParameter3(self):
    m = libsbml.Model(2,2)
    p = libsbml.Parameter(1,2)
    p.setId( "p")
    i = m.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumParameters() == 0 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addParameter4(self):
    m = libsbml.Model(2,2)
    p = None
    i = m.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumParameters() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addParameter5(self):
    m = libsbml.Model(2,2)
    p = libsbml.Parameter(2,2)
    p.setId( "p")
    p1 = libsbml.Parameter(2,2)
    p1.setId( "p")
    i = m.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumParameters() == 1 )
    i = m.addParameter(p1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumParameters() == 1 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addReaction1(self):
    m = libsbml.Model(2,2)
    r = libsbml.Reaction(2,2)
    i = m.addReaction(r)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    r.setId( "r")
    i = m.addReaction(r)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumReactions() == 1 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addReaction2(self):
    m = libsbml.Model(2,2)
    r = libsbml.Reaction(2,1)
    r.setId( "r")
    i = m.addReaction(r)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumReactions() == 0 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addReaction3(self):
    m = libsbml.Model(2,2)
    r = libsbml.Reaction(1,2)
    r.setId( "r")
    i = m.addReaction(r)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumReactions() == 0 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addReaction4(self):
    m = libsbml.Model(2,2)
    r = None
    i = m.addReaction(r)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumReactions() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addReaction5(self):
    m = libsbml.Model(2,2)
    r = libsbml.Reaction(2,2)
    r.setId( "r")
    r1 = libsbml.Reaction(2,2)
    r1.setId( "r")
    i = m.addReaction(r)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumReactions() == 1 )
    i = m.addReaction(r1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumReactions() == 1 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ r1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addRule1(self):
    m = libsbml.Model(2,2)
    r = libsbml.AssignmentRule(2,2)
    i = m.addRule(r)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    r.setVariable( "f")
    i = m.addRule(r)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    r.setMath(libsbml.parseFormula("a-n"))
    i = m.addRule(r)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumRules() == 1 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addRule2(self):
    m = libsbml.Model(2,2)
    r = libsbml.AssignmentRule(2,1)
    r.setVariable( "f")
    r.setMath(libsbml.parseFormula("a-n"))
    i = m.addRule(r)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumRules() == 0 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addRule3(self):
    m = libsbml.Model(2,2)
    r = libsbml.AssignmentRule(1,2)
    r.setVariable( "f")
    r.setMath(libsbml.parseFormula("a-n"))
    i = m.addRule(r)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumRules() == 0 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addRule4(self):
    m = libsbml.Model(2,2)
    r = None
    i = m.addRule(r)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumRules() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addRule5(self):
    m = libsbml.Model(2,2)
    ar = libsbml.AssignmentRule(2,2)
    ar.setVariable( "ar")
    ar.setMath(libsbml.parseFormula("a-j"))
    ar1 = libsbml.AssignmentRule(2,2)
    ar1.setVariable( "ar")
    ar1.setMath(libsbml.parseFormula("a-j"))
    i = m.addRule(ar)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumRules() == 1 )
    i = m.addRule(ar1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumRules() == 1 )
    _dummyList = [ ar ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ar1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpecies1(self):
    m = libsbml.Model(2,2)
    s = libsbml.Species(2,2)
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    s.setId( "s")
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    s.setCompartment( "c")
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumSpecies() == 1 )
    _dummyList = [ s ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpecies2(self):
    m = libsbml.Model(2,2)
    s = libsbml.Species(2,1)
    s.setId( "s")
    s.setCompartment( "c")
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumSpecies() == 0 )
    _dummyList = [ s ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpecies3(self):
    m = libsbml.Model(2,2)
    s = libsbml.Species(1,2)
    s.setId( "s")
    s.setCompartment( "c")
    s.setInitialAmount(2)
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumSpecies() == 0 )
    _dummyList = [ s ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpecies4(self):
    m = libsbml.Model(2,2)
    s = None
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumSpecies() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpecies5(self):
    m = libsbml.Model(2,2)
    s = libsbml.Species(2,2)
    s.setId( "s")
    s.setCompartment( "c")
    s1 = libsbml.Species(2,2)
    s1.setId( "s")
    s1.setCompartment( "c")
    i = m.addSpecies(s)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumSpecies() == 1 )
    i = m.addSpecies(s1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumSpecies() == 1 )
    _dummyList = [ s ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ s1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpeciesType1(self):
    m = libsbml.Model(2,2)
    st = libsbml.SpeciesType(2,2)
    i = m.addSpeciesType(st)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    st.setId( "st")
    i = m.addSpeciesType(st)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumSpeciesTypes() == 1 )
    _dummyList = [ st ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpeciesType2(self):
    m = libsbml.Model(2,2)
    st = libsbml.SpeciesType(2,3)
    st.setId( "st")
    i = m.addSpeciesType(st)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumSpeciesTypes() == 0 )
    _dummyList = [ st ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpeciesType3(self):
    m = libsbml.Model(2,2)
    st = None
    i = m.addSpeciesType(st)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumSpeciesTypes() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addSpeciesType4(self):
    m = libsbml.Model(2,2)
    st = libsbml.SpeciesType(2,2)
    st.setId( "st")
    st1 = libsbml.SpeciesType(2,2)
    st1.setId( "st")
    i = m.addSpeciesType(st)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumSpeciesTypes() == 1 )
    i = m.addSpeciesType(st1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumSpeciesTypes() == 1 )
    _dummyList = [ st ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ st1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addUnitDefinition1(self):
    m = libsbml.Model(2,2)
    ud = libsbml.UnitDefinition(2,2)
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    ud.createUnit()
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    ud.setId( "ud")
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumUnitDefinitions() == 1 )
    _dummyList = [ ud ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addUnitDefinition2(self):
    m = libsbml.Model(2,2)
    ud = libsbml.UnitDefinition(2,1)
    ud.createUnit()
    ud.setId( "ud")
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumUnitDefinitions() == 0 )
    _dummyList = [ ud ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addUnitDefinition3(self):
    m = libsbml.Model(2,2)
    ud = libsbml.UnitDefinition(1,2)
    ud.createUnit()
    ud.setId( "ud")
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumUnitDefinitions() == 0 )
    _dummyList = [ ud ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addUnitDefinition4(self):
    m = libsbml.Model(2,2)
    ud = None
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumUnitDefinitions() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_addUnitDefinition5(self):
    m = libsbml.Model(2,2)
    ud = libsbml.UnitDefinition(2,2)
    ud.setId( "ud")
    ud.createUnit()
    ud1 = libsbml.UnitDefinition(2,2)
    ud1.setId( "ud")
    ud1.createUnit()
    i = m.addUnitDefinition(ud)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumUnitDefinitions() == 1 )
    i = m.addUnitDefinition(ud1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumUnitDefinitions() == 1 )
    _dummyList = [ ud ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ ud1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createCompartment(self):
    m = libsbml.Model(2,2)
    p = m.createCompartment()
    self.assertTrue( m.getNumCompartments() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createCompartmentType(self):
    m = libsbml.Model(2,2)
    p = m.createCompartmentType()
    self.assertTrue( m.getNumCompartmentTypes() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createConstraint(self):
    m = libsbml.Model(2,2)
    p = m.createConstraint()
    self.assertTrue( m.getNumConstraints() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createEvent(self):
    m = libsbml.Model(2,2)
    p = m.createEvent()
    self.assertTrue( m.getNumEvents() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createEventAssignment(self):
    m = libsbml.Model(2,2)
    p = m.createEvent()
    ea = m.createEventAssignment()
    self.assertTrue( p.getNumEventAssignments() == 1 )
    self.assertTrue( (ea).getLevel() == 2 )
    self.assertTrue( (ea).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createFunctionDefinition(self):
    m = libsbml.Model(2,2)
    p = m.createFunctionDefinition()
    self.assertTrue( m.getNumFunctionDefinitions() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createInitialAssignment(self):
    m = libsbml.Model(2,2)
    p = m.createInitialAssignment()
    self.assertTrue( m.getNumInitialAssignments() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createKineticLaw(self):
    m = libsbml.Model(2,2)
    p = m.createReaction()
    kl = m.createKineticLaw()
    self.assertTrue( p.isSetKineticLaw() == True )
    self.assertTrue( (kl).getLevel() == 2 )
    self.assertTrue( (kl).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createKineticLawParameters(self):
    m = libsbml.Model(2,2)
    r = m.createReaction()
    kl = m.createKineticLaw()
    p = m.createKineticLawParameter()
    self.assertTrue( r.isSetKineticLaw() == True )
    self.assertTrue( kl.getNumParameters() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createModifier(self):
    m = libsbml.Model(2,2)
    p = m.createReaction()
    sr = m.createModifier()
    self.assertTrue( p.getNumModifiers() == 1 )
    self.assertTrue( (sr).getLevel() == 2 )
    self.assertTrue( (sr).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createParameter(self):
    m = libsbml.Model(2,2)
    p = m.createParameter()
    self.assertTrue( m.getNumParameters() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createProduct(self):
    m = libsbml.Model(2,2)
    p = m.createReaction()
    sr = m.createProduct()
    self.assertTrue( p.getNumProducts() == 1 )
    self.assertTrue( (sr).getLevel() == 2 )
    self.assertTrue( (sr).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createReactant(self):
    m = libsbml.Model(2,2)
    p = m.createReaction()
    sr = m.createReactant()
    self.assertTrue( p.getNumReactants() == 1 )
    self.assertTrue( (sr).getLevel() == 2 )
    self.assertTrue( (sr).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createReaction(self):
    m = libsbml.Model(2,2)
    p = m.createReaction()
    self.assertTrue( m.getNumReactions() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createRule(self):
    m = libsbml.Model(2,2)
    p = m.createAssignmentRule()
    self.assertTrue( m.getNumRules() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createSpecies(self):
    m = libsbml.Model(2,2)
    p = m.createSpecies()
    self.assertTrue( m.getNumSpecies() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createSpeciesType(self):
    m = libsbml.Model(2,2)
    p = m.createSpeciesType()
    self.assertTrue( m.getNumSpeciesTypes() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createUnit(self):
    m = libsbml.Model(2,2)
    p = m.createUnitDefinition()
    u = m.createUnit()
    self.assertTrue( p.getNumUnits() == 1 )
    self.assertTrue( (u).getLevel() == 2 )
    self.assertTrue( (u).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_createUnitDefinition(self):
    m = libsbml.Model(2,2)
    p = m.createUnitDefinition()
    self.assertTrue( m.getNumUnitDefinitions() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_setId1(self):
    id =  "1e1";
    i = self.M.setId(id)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.M.isSetId() )
    pass  

  def test_Model_setId2(self):
    id =  "e1";
    i = self.M.setId(id)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue(( id == self.M.getId() ))
    self.assertEqual( True, self.M.isSetId() )
    i = self.M.setId("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetId() )
    pass  

  def test_Model_setId3(self):
    id =  "e1";
    i = self.M.setId(id)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue(( id == self.M.getId() ))
    self.assertEqual( True, self.M.isSetId() )
    i = self.M.unsetId()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetId() )
    pass  

  def test_Model_setModelHistory1(self):
    self.M.setMetaId("_001")
    mh = libsbml.ModelHistory()
    i = self.M.setModelHistory(mh)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    self.assertEqual( False, self.M.isSetModelHistory() )
    i = self.M.unsetModelHistory()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetModelHistory() )
    _dummyList = [ mh ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Model_setModelHistory2(self):
    self.M.setMetaId("_001")
    i = self.M.setModelHistory(None)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetModelHistory() )
    i = self.M.unsetModelHistory()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetModelHistory() )
    pass  

  def test_Model_setName1(self):
    name =  "3Set_k2";
    i = self.M.setName(name)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.M.isSetName() )
    pass  

  def test_Model_setName2(self):
    name =  "Set k2";
    i = self.M.setName(name)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue(( name == self.M.getName() ))
    self.assertEqual( True, self.M.isSetName() )
    i = self.M.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetName() )
    pass  

  def test_Model_setName3(self):
    i = self.M.setName("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.M.isSetName() )
    pass  

  def test_Model_setName4(self):
    m = libsbml.Model(1,2)
    i = m.setName( "11dd")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, m.isSetName() )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestModel_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)




#
# @file    TestSpeciesType_newSetters.py
# @brief   SpeciesType unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestSpeciesType_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestSpeciesType_newSetters(unittest.TestCase):

  global ST
  ST = None

  def setUp(self):
    self.ST = libsbml.SpeciesType(2,2)
    if (self.ST == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.ST ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_SpeciesType_setId2(self):
    i = self.ST.setId( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.ST.isSetId() )
    pass  

  def test_SpeciesType_setId3(self):
    i = self.ST.setId( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.ST.isSetId() )
    self.assertTrue((  "cell"  == self.ST.getId() ))
    pass  

  def test_SpeciesType_setId4(self):
    i = self.ST.setId( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.ST.isSetId() )
    self.assertTrue((  "cell"  == self.ST.getId() ))
    i = self.ST.setId("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.ST.isSetId() )
    pass  

  def test_SpeciesType_setName1(self):
    i = self.ST.setName( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.ST.isSetName() )
    i = self.ST.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.ST.isSetName() )
    pass  

  def test_SpeciesType_setName2(self):
    i = self.ST.setName( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.ST.isSetName() )
    i = self.ST.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.ST.isSetName() )
    pass  

  def test_SpeciesType_setName3(self):
    i = self.ST.setName( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.ST.isSetName() )
    i = self.ST.setName("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.ST.isSetName() )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestSpeciesType_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)




#!/usr/bin/env python
#
# @file    generate-pkg-stylesheet.py
# @brief   Create a stylesheet for libSBML package extensions
# @author  Michael Hucka
#
# Usage:
#   generate-pkg-stylesheet.py PACKAGE-SRC-DIR > libsbml-package-stylesheet.css
#
# where
#   PACKAGE-SRC-DIR = the path to the libSBML src/sbml/packages directory
#
# This program looks in the root of the libSBML source directory for package
# plug-ins that are distributed with libSBML (i.e., for accepted SBML Level 3
# packages) and generates a CSS stylesheet for both the Doxygen-based and
# Javadoc-based API documentation.  To do the desired styling for the Javadoc
# documentation, this program has to know the object classes that are defined
# by each libSBML package plug-in.  Since this may change over time, it
# is better to look in the source directory for the current class definitions
# than to hard code them in a CSS file or this file.  That is the motivation
# for this program.
#
# <!--------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright (C) 2013-2018 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#     3. University of Heidelberg, Heidelberg, Germany
#
# Copyright (C) 2009-2013 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#
# Copyright (C) 2006-2008 by the California Institute of Technology,
#     Pasadena, CA, USA
#
# Copyright (C) 2002-2005 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. Japan Science and Technology Agency, Japan
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# ---------------------------------------------------------------------- -->*/

import os, sys, re
from os.path import join
sys.path.append('../../../src/bindings/swig')
sys.path.append('../../src/bindings/swig')
from libsbmlutils import find_classes


color_table = [
    # Name,   red,   green,   blue
    ['comp',    '220',  '220',  '220'],
    ['fbc',     '190',  '230',  '215'],
    ['layout',  '250',  '230',  '170'],
    ['qual',    '160',  '185',  '235'],
    ['multi',   '120',  '120',  '120'],
    ['groups',  '242',  '169',  '135'],
    ['arrays',  '0',    '150',  '132'],
    ['distrib', '243',  '250',  '134'],
    ['spatial', '223',  '170',  '20'],
    ['render',  '77',   '168',  '170'],
]


header_template = '''/**
 * WARNING -- THIS FILE IS AUTO-GENERATED -- DO NOT EDIT THIS FILE
 *
 * @file    libsbml-package-stylesheet.css
 * @brief   Stylesheet used by libSBML for L3 package plug-in docs.
 * @author  libSBML Team <libsbml-team@googlegroups.com>
 *
 * This file is generated by generate-pkg-stylesheet.py in the libSBML
 * documentation source directory.  DO NOT EDIT THIS FILE DIRECTLY
 * BECAUSE YOUR CHANGES WILL BE LOST WHEN THE FILE IS REGENERATED.
 *
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 */
'''


pkg_separator_template = '''
/* Styling for package '{}' used in libSBML Javadoc output */
'''


pkg_style_template = '''.pkg-color-{0} 
{{
    border: 1px solid rgb({1}, {2}, {3});
    background-color: rgba({1}, {2}, {3}, 0.35);
}}
'''


group_page_ref_template = '''{
    font-family: "Noto Sans", Verdana, Helvetica, Arial, Sans, sans-serif !important;
    font-weight: normal;
    font-size: 12px;
}
'''


safari_bugfix_template = '''{
    display: inline-block;
    margin-left: 0px;
}
'''


before_template = '''{{
    content: "\\25cf";
    color: rgb({1}, {2}, {3});
    margin-right: 0.25em;
}}
'''


after_template = '''{{
    content: "{0}";
    display: inline-block;
    font-family: "Noto Sans", Verdana, Helvetica, Arial, Sans, sans-serif;
    font-size: 80%;
    font-style: italic;
    font-weight: normal;
    line-height: 100%;
    text-align: center;
    color: #000 !important;
    background-color: rgba({1}, {2}, {3}, 0.35);
    border: 1px solid rgb({1}, {2}, {3});
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    margin-left: 1em;
    padding: 1px 3px;
    min-width: 40px;
    width: 40px;
}}
'''


def main(args):
    if len(args) != 2:
      print ("Must be given one argument: the path to the package source dir")
      sys.exit(1)

    src_dir = args[1]

    # First, write out an informative file header.
    print (header_template)

    # Next, write out the .pkg-color-x CSS classes:
    for entry in color_table:
        print (pkg_style_template.format(entry[0], entry[1], entry[2], entry[3]))

    # Next, write rules for general references to the summary pages for packages.
    print ('/* Styles for references to the package summary pages. */\n')
    for entry in color_table:
        print ('p a.el[href="group__{}.html"]'.format(entry[0]))
        print (group_page_ref_template)

    # Next, read the source dir to find out the L3 packages available, and
    # extract the names of the libSBML object classes in each package.
    known_pkgs = [entry[0] for entry in color_table]
    top_root, top_level_dirs, top_level_files = next(os.walk(src_dir))
    found_pkgs = [pkg for pkg in known_pkgs if pkg in top_level_dirs]

    # Now generate CSS styling that uses attribute selectors specialized to
    # our Javadoc output.  These styles are ignored by our Doxygen output
    # (because the CSS code doesn't match anything there), so technically we
    # could split this into a separate file for Javadoc-only styling, but
    # it's easier to write all our package CSS code into one file.
    for pkg in found_pkgs:
        print (pkg_separator_template.format(pkg))

        color   = next(entry for entry in color_table if entry[0] == pkg)
        classes = find_classes(os.path.join(src_dir, pkg), enums_too = False)
        last    = classes[-1]

        # There is a spectacularly obscure bug in Safari that necessitates
        # first writing CSS rules that use the same attribute selectors we
        # use later, but without using pseudo elements.  Here, we output a
        # benign bit of CSS that doesn't change anything.  See
        # http://stackoverflow.com/a/8988418/743730
        for c in classes:
            # This next format works for Javadoc version 1.6:
            print ('.FrameItemFont a[href$="{}.html"],'.format(c))
            # This next format works for Javadoc versions after version 1.6:
            comma = (',' if c != last else '')
            print ('.indexContainer a[href$="{}.html"]{}'.format(c, comma))
        print (safari_bugfix_template)

        # With that out of the way, we can write the real CSS.
        for c in classes:
            # This next format works for Javadoc version 1.6:
            print ('.FrameItemFont a[href$="{}.html"]:before,'.format(c))
            # This next format works for Javadoc versions after version 1.6:
            comma = (',' if c != last else '')
            print ('.indexContainer a[href$="{}.html"]:before{}'.format(c, comma))
        print (before_template.format(pkg, color[1], color[2], color[3]))

        for c in classes:
            # This next format works for Javadoc version 1.6:
            print ('.FrameItemFont a[href$="{}.html"]:after,'.format(c))
            # This next format works for Javadoc versions after version 1.6:
            comma = (',' if c != last else '')
            print ('.indexContainer a[href$="{}.html"]:after{}'.format(c, comma))
        print (after_template.format(pkg, color[1], color[2], color[3]))

    # A final bit of styling for Doxygen output.
    print ('/* Styles for page headings and "Level 3 Extensions" section. */\n')
    for entry in color_table:
        print ('.title .ingroups a[href="group__{}.html"]:after,'.format(entry[0]))
        print ('#navrow2 ul.tablist li a[href="group__{}.html"]:after,'.format(entry[0]))
        print ('.contents ul li a[href="group__{}.html"]:after'.format(entry[0]))
        print (after_template.format(entry[0], entry[1], entry[2], entry[3]))



if __name__ == '__main__':
  main(sys.argv)



#
# @file    TestParameter_newSetters.py
# @brief   Parameter unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestParameter_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestParameter_newSetters(unittest.TestCase):

  global P
  P = None

  def setUp(self):
    self.P = libsbml.Parameter(1,2)
    if (self.P == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.P ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Parameter_setConstant1(self):
    i = self.P.setConstant(False)
    self.assertTrue( i == libsbml.LIBSBML_UNEXPECTED_ATTRIBUTE )
    self.assertTrue( self.P.getConstant() == False )
    pass  

  def test_Parameter_setConstant2(self):
    p = libsbml.Parameter(2,2)
    i = p.setConstant(False)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( p.getConstant() == False )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Parameter_setId1(self):
    i = self.P.setId( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.P.isSetId() )
    pass  

  def test_Parameter_setId2(self):
    i = self.P.setId( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.P.isSetId() )
    self.assertTrue((  "cell"  == self.P.getId() ))
    i = self.P.setId("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.P.isSetId() )
    pass  

  def test_Parameter_setName1(self):
    i = self.P.setName( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.P.isSetName() )
    i = self.P.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.P.isSetName() )
    pass  

  def test_Parameter_setName2(self):
    p = libsbml.Parameter(2,2)
    i = p.setName( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, p.isSetName() )
    i = p.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, p.isSetName() )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Parameter_setName3(self):
    p = libsbml.Parameter(1,2)
    i = p.setName( "11pp")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, p.isSetName() )
    i = p.setName("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, p.isSetName() )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Parameter_setUnits1(self):
    i = self.P.setUnits( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.P.isSetUnits() )
    i = self.P.unsetUnits()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.P.isSetUnits() )
    pass  

  def test_Parameter_setUnits2(self):
    i = self.P.setUnits( "litre")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.P.isSetUnits() )
    i = self.P.unsetUnits()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.P.isSetUnits() )
    pass  

  def test_Parameter_setUnits3(self):
    i = self.P.setUnits("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.P.isSetUnits() )
    pass  

  def test_Parameter_setValue1(self):
    i = self.P.setValue(2.0)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.P.getValue() == 2.0 )
    self.assertEqual( True, self.P.isSetValue() )
    i = self.P.unsetValue()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.P.isSetValue() )
    pass  

  def test_Parameter_setValue2(self):
    p = libsbml.Parameter(2,2)
    i = p.unsetValue()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, p.isSetValue() )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestParameter_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/bin/env python
import libsbml
import sys


def print_gene_product_association(file_name):
    doc = libsbml.readSBMLFromFile(file_name)
    assert (isinstance(doc, libsbml.SBMLDocument))

    if doc.getNumErrors(libsbml.LIBSBML_SEV_ERROR) > 0:
        print("There were errors while reading, better to fix those first")
        doc.printErrors()
        sys.exit(1)

    model = doc.getModel()
    if model is None:
        print("document has no model, bailing")

    num_reactions = model.getNumReactions()
    print("      Model: %s" % model.getName())
    print("# reactions: %d" % num_reactions)

    for reaction in model.getListOfReactions():
        print(" Reaction: %s" % reaction.getId())
        plugin = reaction.getPlugin('fbc')
        if plugin is None:
            # not relevant for us
            continue

        if not plugin.isSetGeneProductAssociation():
            continue

        gpa = plugin.getGeneProductAssociation()

        association = gpa.getAssociation()
        print ("    Association: %s" % association.toInfix())

    print("done")


if __name__ == "__main__":
    argc = len(sys.argv)
    model_file = 'iJO1366.xml.gz'
    if argc > 1:
        model_file = sys.argv[1]
    print_gene_product_association(model_file)



#!/usr/bin/env python
## 
## @file    translateMath.py
## @brief   Translates infix formulas into MathML and vice-versa
## @author  Sarah Keating
## @author  Ben Bornstein
## 
## 
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->
## 

import sys
import time
import os
import os.path
from libsbml import *


#
# Translates the given infix formula into MathML.
#
# @return the MathML as a string.  The caller owns the memory and is
# responsible for freeing it.
#
def translateInfix(formula):
    math = parseFormula(formula)
    return writeMathMLToString(math)


#
# Translates the given MathML into an infix formula.  The MathML must
# contain no leading whitespace, but an XML header is optional.
# 
# @return the infix formula as a string.  The caller owns the memory and
# is responsible for freeing it.
# 
def translateMathML(xml):
    math = readMathMLFromString(xml)
    return formulaToString(math)


def main(args):
    """Usage: readSBML filename
    """

    print("This program translates infix formulas into MathML and")
    print("vice-versa.  Enter or return on an empty line triggers")
    print("translation. Ctrl-C quits")

    sb = ""
    try:
        while True:
            print("Enter infix formula or MathML expression (Ctrl-C to quit):")
            print("> ")

            line = sys.stdin.readline()
            while line is not None:
                trimmed = line.strip()
                length = len(trimmed)
                if length > 0:
                    sb = sb + trimmed
                else:
                    str = sb
                    result = ""
                    if str[0] == '<':
                        result = translateMathML(str)
                    else:
                        result = translateInfix(str)

                    print("Result:\n\n" + result + "\n\n")
                    sb = ""
                    break

                line = sys.stdin.readline()
    except:
        pass
    return 0


if __name__ == '__main__':
    main(sys.argv)



#
# @file    TestL3Unit.py
# @brief   L3 Unit unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestL3Unit.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def isnan(x):
  return (x != x)
  pass
SBML_INT_MAX = 2147483647

class TestL3Unit(unittest.TestCase):

  global U
  U = None

  def setUp(self):
    self.U = libsbml.Unit(3,1)
    if (self.U == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.U ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Unit_NS(self):
    self.assertTrue( self.U.getNamespaces() != None )
    self.assertTrue( self.U.getNamespaces().getLength() == 1 )
    self.assertTrue((     "http://www.sbml.org/sbml/level3/version1/core" == self.U.getNamespaces().getURI(0) ))
    pass  

  def test_L3_Unit_create(self):
    self.assertTrue( self.U.getTypeCode() == libsbml.SBML_UNIT )
    self.assertTrue( self.U.getMetaId() == "" )
    self.assertTrue( self.U.getNotes() == None )
    self.assertTrue( self.U.getAnnotation() == None )
    self.assertTrue( self.U.getKind() == libsbml.UNIT_KIND_INVALID )
    self.assertEqual( True, isnan(self.U.getExponentAsDouble()) )
    self.assertEqual( True, isnan(self.U.getMultiplier()) )
    self.assertTrue( self.U.getScale() == SBML_INT_MAX )
    self.assertEqual( False, self.U.isSetKind() )
    self.assertEqual( False, self.U.isSetExponent() )
    self.assertEqual( False, self.U.isSetMultiplier() )
    self.assertEqual( False, self.U.isSetScale() )
    pass  

  def test_L3_Unit_createWithNS(self):
    xmlns = libsbml.XMLNamespaces()
    xmlns.add( "http://www.sbml.org", "testsbml")
    sbmlns = libsbml.SBMLNamespaces(3,1)
    sbmlns.addNamespaces(xmlns)
    u = libsbml.Unit(sbmlns)
    self.assertTrue( u.getTypeCode() == libsbml.SBML_UNIT )
    self.assertTrue( u.getMetaId() == "" )
    self.assertTrue( u.getNotes() == None )
    self.assertTrue( u.getAnnotation() == None )
    self.assertTrue( u.getLevel() == 3 )
    self.assertTrue( u.getVersion() == 1 )
    self.assertTrue( u.getNamespaces() != None )
    self.assertTrue( u.getNamespaces().getLength() == 2 )
    self.assertTrue( u.getKind() == libsbml.UNIT_KIND_INVALID )
    self.assertEqual( True, isnan(u.getExponentAsDouble()) )
    self.assertEqual( True, isnan(u.getMultiplier()) )
    self.assertEqual( False, u.isSetKind() )
    self.assertEqual( False, u.isSetExponent() )
    self.assertEqual( False, u.isSetMultiplier() )
    self.assertEqual( False, u.isSetScale() )
    _dummyList = [ u ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Unit_exponent(self):
    exponent = 0.2
    self.assertEqual( False, self.U.isSetExponent() )
    self.assertEqual( True, isnan(self.U.getExponentAsDouble()) )
    self.U.setExponent(exponent)
    self.assertTrue( self.U.getExponentAsDouble() == exponent )
    self.assertEqual( True, self.U.isSetExponent() )
    pass  

  def test_L3_Unit_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Unit_hasRequiredAttributes(self):
    u = libsbml.Unit(3,1)
    self.assertEqual( False, u.hasRequiredAttributes() )
    u.setKind(libsbml.UNIT_KIND_MOLE)
    self.assertEqual( False, u.hasRequiredAttributes() )
    u.setExponent(0)
    self.assertEqual( False, u.hasRequiredAttributes() )
    u.setMultiplier(0.45)
    self.assertEqual( False, u.hasRequiredAttributes() )
    u.setScale(2)
    self.assertEqual( True, u.hasRequiredAttributes() )
    _dummyList = [ u ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_Unit_kind(self):
    kind =  "mole";
    self.assertEqual( False, self.U.isSetKind() )
    self.U.setKind(libsbml.UnitKind_forName(kind))
    self.assertTrue( self.U.getKind() == libsbml.UNIT_KIND_MOLE )
    self.assertEqual( True, self.U.isSetKind() )
    pass  

  def test_L3_Unit_multiplier(self):
    multiplier = 0.2
    self.assertEqual( False, self.U.isSetMultiplier() )
    self.assertEqual( True, isnan(self.U.getMultiplier()) )
    self.U.setMultiplier(multiplier)
    self.assertTrue( self.U.getMultiplier() == multiplier )
    self.assertEqual( True, self.U.isSetMultiplier() )
    pass  

  def test_L3_Unit_scale(self):
    scale = 2
    self.assertEqual( False, self.U.isSetScale() )
    self.assertTrue( self.U.getScale() == SBML_INT_MAX )
    self.U.setScale(scale)
    self.assertTrue( self.U.getScale() == scale )
    self.assertEqual( True, self.U.isSetScale() )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestL3Unit))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)

